@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 """
-======================================================================
+===============================================================
 Package for generating nano-structures (:mod:`sknano.nanogen`)
-======================================================================
+===============================================================
 
 .. currentmodule:: sknano.nanogen
 
@@ -20,9 +20,6 @@ and bundles of :abbr:`SWNTs` and :abbr:`MWNTs`.
 .. versionadded:: 0.2.8
    `MWNTGenerator` implemented
 
-.. versionadded:: 0.2.6
-   `GrapheneVacancyGenerator` and `NanotubeVacancyGenerator` implemented
-
 .. versionadded:: 0.2.4
    `NanotubeBundleGenerator` implemented
 
@@ -56,16 +53,6 @@ Structure generator classes
 
 .. seealso:: CLI module :py:mod:`sknano.scripts.nanogen`
 
-Classes for changing structures
--------------------------------
-
-.. autosummary::
-   :toctree: generated/
-
-   VacancyGenerator
-   GrapheneVacancyGenerator
-   NanotubeVacancyGenerator
-
 Custom exception classes for handling errors
 --------------------------------------------
 
@@ -74,7 +61,6 @@ Custom exception classes for handling errors
 
    GrapheneGeneratorError
    NanotubeGeneratorError
-   VacancyGeneratorError
 
 """
 from __future__ import division, print_function, absolute_import
@@ -86,6 +72,5 @@ from ._graphene_generator import *
 from ._nanotube import *
 from ._nanotube_generator import *
 from ._tubegen import *
-from ._vacancy_generator import *
 
 __all__ = [s for s in dir() if not s.startswith('_')]
